module.exports = function(grunt) {

  require('load-grunt-tasks')(grunt);

  // Project configuration.
  grunt.initConfig({
	pkg: grunt.file.readJSON('package.json'),

	// # docs
	wp_readme_to_markdown: {
		convert:{
			files: {
				'readme.md': 'readme.txt'
			},
		},
	},

	// # Internationalization

	// Add text domain
	addtextdomain: {
		options: {
			textdomain: '<%= pkg.name %>',    // Project text domain.
			updateDomains: [ '<%= pkg.name %>' ]  // List of text domains to replace.
		},
		target: {
			files: {
				src: ['*.php', '**/*.php', '**/**/*.php', '!node_modules/**', '!deploy/**']
			}
		}
	},

	// Generate .pot file
	makepot: {
		target: {
			options: {
				domainPath: '/languages', // Where to save the POT file.
				exclude: ['deploy'], // List of files or directories to ignore.
				mainFile: '<%= pkg.name %>.php', // Main project file.
				potFilename: '<%= pkg.name %>.pot', // Name of the POT file.
				type: 'wp-plugin' // Type of project (wp-plugin or wp-theme).
			}
		}
	},

	// bump version numbers
	replace: {
		Version: {
			src: [
				'readme.txt',
				'readme.md',
				'<%= pkg.name %>.php'
			],
			overwrite: true,
			replacements: [
				{
					from: /Stable tag:.*$/m,
					to: "Stable tag: <%= pkg.version %>"
				},
				{
					from: /\*\*Stable tag:.*$/m,
					to: "**Stable tag:** <%= pkg.version %>"
				},
				{
					from: /Version:.*$/m,
					to: "Version: <%= pkg.version %>"
				},
				{
					from: /const VERSION = \'.*.'/m,
					to: "const VERSION = '<%= pkg.version %>'"
				},

			]
		}
	},
	clean: {
		main: {
			src: ["build"]
		}
	},
	copy: {
		main: {
			src:  [
				'**',
				'!node_modules/**',
				'!yeoman-template/**',
				'!.sass-cache/**',
				'!build/**',
				'!.git/**',
				//'!.gitignore',
				'!*~',
				'!*.sublime-workspace',
				'!*.sublime-project',
			],
			dest: 'build/',
		},
	}

});

grunt.registerTask( 'docs', [ 'wp_readme_to_markdown'] );

grunt.registerTask( 'default', [ 'addtextdomain', 'makepot', 'wp_readme_to_markdown' ] );

grunt.registerTask( 'build', [ 'addtextdomain', 'makepot', 'wp_readme_to_markdown', 'clean:main', 'copy:main'] );

};
