<?php
/**
 * Functions related to the "affilae_rule" custom post-type
 *
 * @class 	WC_Affilae_Rule
 * @version 1.0.0
 * @since   1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class WC_Affilae_Rule {

	/**
	 * __construct function.
	 *
	 * @access public
	 *
	 * @return void
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'create_post_type' ), 10 );
		add_action( 'admin_menu', array( $this, 'remove_category_submenu' ), 20 );
		add_action( 'add_meta_boxes', array( $this, 'remove_yoast_metabox_affilae_rules' ), 10 );
		add_action( 'add_meta_boxes', array( $this, 'add_affilae_rules_metabox' ), 20 );
		add_action( 'save_post', array( $this, 'save_affilae_rule' ), 10, 3 );
		add_filter( 'enter_title_here', array( $this, 'affilae_rule_entertitlehere' ) );
		add_filter( 'admin_notices', array( $this, 'affilae_rule_admin_notice' ) );
	}


	/**
	 * Create the affilae_rule post type
	 *
	 * @access public
	 *
	 * @return void
	 */
	public function create_post_type() {
		register_post_type( 'affilae_rule', array(
			'labels' => array(
				'name'          => __( 'Affilae rules', 'woocommerce-affilae' ),
				'singular_name' => __( 'Affilae rule', 'woocommerce-affilae' ),
				'add_new'       => __( 'Add New', 'woocommerce-affilae' ),
				'add_new_item'  => __( 'Add New Affilae rule', 'woocommerce-affilae' ),
				'edit_item'     => __( 'Edit Affilae rule', 'woocommerce-affilae' ),
				'new_item'      => __( 'New Affilae rule', 'woocommerce-affilae' ),
				'view_item'     => __( 'View Affilae rule', 'woocommerce-affilae' )
			),

			'public'              => false,
			'publicly_queriable'  => true,
			'show_ui'             => true,
			'exclude_from_search' => true,
			'show_in_nav_menus'   => false,
			'has_archive'         => false,
			'rewrite'             => false,
			'menu_position'       => 100,
			'show_in_menu'        => 'woocommerce',

			'supports' => array(
				'title'
			),
			'taxonomies' => array(
				'product_cat'
			)
		) );
	}


	/**
	 * Remove the yoast metabox on the affilae page
	 *
	 * @access public
	 *
	 * @return void
	 */
	public function remove_yoast_metabox_affilae_rules() {
		remove_meta_box('wpseo_meta', 'affilae_rule', 'normal');
	}


	/**
	 * Add the affilae rule metaboxes
	 *
	 * @access public
	 *
	 * @return void
	 */
	public function add_affilae_rules_metabox() {
		add_meta_box(
			'wc_affilae_code',
			__( 'Conversion code', 'woocommerce-affilae' ),
			array( $this, 'wc_affilae_code' ),
			'affilae_rule',
			'normal',
			'default'
		);
	}


	/**
	 * Display the affilae code field
	 *
	 * @access public
	 *
	 * @param  int $meta_id
	 *
	 * @return string
	 */
	public function wc_affilae_code( $meta_id ) {
		$_code = get_post_meta( $meta_id->ID, '_code', true );

		$outline = '<p class="form-field">';
		$outline .= '<label for="_code" class="hidden">'. esc_html__('Code', 'woocommerce-affilae') .'</label>';
		$outline .= '<input type="text" name="_code" id="_code" class="wide-fat" value="'. esc_attr($_code) .'" />';
		$outline .= '</p>';

		echo $outline;
	}

	/**
	 * Save the Affilae rule custom fields into the database
	 *
	 * @access public
	 *
	 * @param  int 	$meta_id
	 * @param  post $post
	 *
	 * @return string
	 */
	public function save_affilae_rule( $post_id, $post ) {
		/*
		 * In production code, $slug should be set only once in the plugin,
		 * preferably as a class property, rather than in each function that needs it.
		 */
		$post_type = get_post_type( $post_id );

		// If this isn't a 'affilae_rule' post, don't update it.
		if ( 'affilae_rule' != $post_type ) {
			return;
		}

		// - Update the post's metadata.
		if ( isset( $_POST['_code'] ) ) {
			update_post_meta( $post_id, '_code', sanitize_text_field( $_POST['_code'] ) );
		}
	}


	/**
	 * Change the placeholder of the rule title
	 *
	 * @access public
	 *
	 * @param  string $title
	 *
	 * @return string
	 */
	public function affilae_rule_entertitlehere( $title ) {
		$screen = get_current_screen();

		if ($screen->post_type === 'affilae_rule') {
			$title = __('Rule name', 'woocommerce-affilae');
		}

		return $title;
	}


	/**
	 * Remove the WooCommerce category submenu in the admin
	 *
	 * @access public
	 *
	 * @return void
	 */
	public function remove_category_submenu() {
		remove_submenu_page( 'edit.php?post_type=affilae_rule', 'edit-tags.php?taxonomy=product_cat&amp;post_type=affilae_rule' );
	}

	/**
	 * Add a notice in the affilae rule
	 *
	 * @access public
	 *
	 * @return void
	 */
	public function affilae_rule_admin_notice()
	{
		$screen = get_current_screen();

		if ( $screen->id === 'affilae_rule' ) {
			echo '<div class="updated">
				<p>' . __('By default all categories are selected. If you want to apply your commission rules to one or more specific categories, select them. To apply your rule(s) on all product categories, please leave blank.', 'woocommerce-affilae') . '</p>
				<p>' . __('NB: If a product belongs to multiple categories then the rule of the first category will be applied..', 'woocommerce-affilae') . '</p>
			</div>';
		}
	}
}
